/********************************************************
* Name  : Atul Nayak					*
* viewer.cxx : Methods of class viewer			*
********************************************************/
	
#include "common.hxx"		// a common header file
#include "viewer.hxx"		// the viewer header file

// Initialize the camera 
void viewer::initialize(int x, int y)
{
	positionX = x;
	positionY = y;

	eyesX = (x * 5.0) + 2.5;		
	eyesY = ((y * 5.0) + 2.5);
	eyesZ = 5.0;
	angle = 0.0;

	currentPositionX = eyesX/5.0;
	currentPositionY = eyesY/5.0;
	
	seeX = ((x - 1) * 5.0) + 2.5;
	seeY = eyesY;
	seeZ = eyesZ;
}

// return eyesX
float viewer::getEyesX()
{
	return eyesX;
}

// return eyesY
float viewer::getEyesY()
{
	return eyesY;
}

// return eyesZ
float viewer::getEyesZ()
{
	return eyesZ;
}

// turn the camera to the left
void viewer::turnLeft()
{
	angle+=1.5;					// change angle	
	seeX = eyesX - (5.0 * cosf(angle * PI/180.0));	// change seeX
	seeY = eyesY - (5.0 * sinf(angle * PI/180.0));  // change seeY
}

// turn the camera to the right
void viewer::turnRight()
{
	angle-=1.5;					// change angle
	seeX = eyesX - (5.0 * cosf(angle * PI/180.0));	// change seeX
	seeY = eyesY - (5.0 * sinf(angle * PI/180.0));	// change seeY
}

// move the camera forward
void viewer::moveForward()
{
	currentPositionX = eyesX/5.0;	// the current positions in the maze array
	currentPositionY = eyesY/5.0;

	currentEyesX = eyesX;		// current position sin the 3D maze
	currentEyesY = eyesY;

	eyesX -= cosf(angle * (PI/180));	// calculate the eyes position
	eyesY -= sinf(angle * (PI/180));
	seeX = eyesX - cosf(angle * (PI/180));	// the see positions shouold also change
	seeY = eyesY - sinf(angle * (PI/180));
			
	nextPositionX = eyesX/5.0;	// next position in the maze array
	nextPositionY = eyesY/5.0;

	nextEyesX = eyesX;		// next position in the 3D maze
	nextEyesY = eyesY;

}

// move to the old X and new Y position
void viewer::oldXnewY()
{
	eyesX = currentEyesX;
	eyesY = nextEyesY;
	seeX = eyesX - cosf(angle * (PI/180));
	seeY = eyesY - sinf(angle * (PI/180));
}

// move to the next X and old Y position
void viewer::newXoldY()
{
	eyesX = nextEyesX;
	eyesY = currentEyesY;
	seeX = eyesX - cosf(angle * (PI/180));
	seeY = eyesY - sinf(angle * (PI/180));
}

// move back to the old X and old Y position
void viewer::oldXoldY()
{
	eyesX = currentEyesX;
	eyesY = currentEyesY;
	seeX = eyesX - cosf(angle * (PI/180));
	seeY = eyesY - sinf(angle * (PI/180));
}

// return currentPositionX
int viewer::getCurrentPositionX()
{
	return currentPositionX;
}

// return currentPositionY
int viewer::getCurrentPositionY()
{
	return currentPositionY;
}

// return nextPositionX
int viewer::getNextPositionX()
{
	return nextPositionX;
}

// return nextPositionY
int viewer::getNextPositionY()
{
	return nextPositionY;
}

// return currentEyesX
float viewer::getCurrentEyesX()
{
	return currentEyesX;
}

// return currentEyesX
float viewer::getCurrentEyesY()
{
	return currentEyesY;
}

// return nextEyesX
float viewer::getNextEyesX()
{
	return nextEyesX;
}

// return nextEyesY
float viewer::getNextEyesY()
{
	return nextEyesY;
}

// change the position of the camera to the values specified
// this is used when you are teleported 
void viewer::changeEyes(int newEyesX, int newEyesY)
{
	eyesX = (newEyesX * 5.0) + 2.5;
	eyesY = ((newEyesY * 5.0) + 2.5);
	seeX = eyesX - cosf(angle * (PI/180));
	seeY = eyesY - sinf(angle * (PI/180));
}

// decide where the camera is positioned and where it is looking at 
void viewer::lookAt()
{
	glMatrixMode(GL_MODELVIEW);
	glLoadIdentity();
	gluLookAt(eyesX, eyesY, eyesZ, seeX, seeY, seeZ, 0.0, 0.0, 1.0);
}
