/****************************************************************	
* Name : Atul Nayak						*
* start.cxx : Methods of class start				*
****************************************************************/	     

#include "common.hxx"
#include "wall.hxx"

//constructor - reads wall.txt
wall::wall()
{ 
	int tmp_noOfVertices;
	float tmp_vertex1;
	float tmp_vertex2;
	float tmp_vertex3;

	// open the file in read mode	
	FILE* fp1 = fopen(wallfile,"r");	
	if (!fp1)		// error
	{
		printf("Couldn't open file wall.txt\n");
		exit(1);
	}

	// read no of polygons on first line
	fscanf(fp1,"%d\n", &noOfPolygons);
	fscanf(fp1,"\n");

	// read in the color scheme on second line
	fscanf(fp1,"%f %f %f", &colors[0], &colors[1], &colors[2]);
	fscanf(fp1,"\n");

	// read in the no of vertices in each polygon
	// and the vertcies themselves	
	for (int i = 0; i < noOfPolygons; i++)
	{
		fscanf(fp1, "%d", &tmp_noOfVertices);
		noOfVertices.push_back(tmp_noOfVertices);
		fscanf(fp1,"\n");
		for (int k =0 ; k < tmp_noOfVertices; k++)
		{
			fscanf(fp1, "%f %f %f", &tmp_vertex1, &tmp_vertex2, &tmp_vertex3);
			vertices.push_back(tmp_vertex1);
			vertices.push_back(tmp_vertex2);
			vertices.push_back(tmp_vertex3);
			fscanf(fp1,"\n");
		}
	}
	fclose(fp1);
	wallIsDoor = FALSE;	// set flag to flase	

}

// draw wall at the specified position
void wall::drawWall(int x, int y)
{
	positionX = x;
	positionY = y;

	// calculate the edge values
	leftEdge = x * 5.0;
	rightEdge = leftEdge + 5.0;
	bottomEdge = y * 5.0;
	topEdge = bottomEdge + 5.0;		

	// apply transformations
	glPushMatrix();
		glTranslatef((x*5.0)+2.5,(y*5.0)+2.5,0);	
		glColor3f(colors[0], colors[1], colors[2]);
		int i =0;		// i keeps track of the no of coordinates
		for (int j = 0; j < noOfPolygons; j++)
		{
			glBegin(GL_LINE_LOOP);
				int g=0;	// g tracks no of corners in the polygon
				for ( ; g < noOfVertices[j]; i+=3, g++)
					glVertex3f(vertices[i], vertices[i+1], vertices[i + 2]);
//			printf("i is %d\n", i);
//			printf("%.2f %.2f %.2f\n", vertices[i], vertices[i+1], vertices[i + 2]);
			glEnd();
		}
	glPopMatrix();
	
}

// returns positionX
int wall::getPositionX()
{
	return positionX;
}

// returns positionY
int wall::getPositionY()
{
	return positionY;
}

// set the wall color to it's maximum intensity
void wall::brightestColor()
{
	// if there is any other object embedded in a wall
	// let the wall be transparent
	if (!wallIsDoor)
	{
		colors[0] = 1.0;
		colors[1] = 0.0;		
		colors[2] = 0.0;		
	}
}

// set the wall color to it's minimum intensity
void wall::darkestColor()
{
	colors[0] = 0.0;
	colors[1] = 0.0;		
	colors[2] = 0.0;		
}

// set the wall color to an intermediate value specified
void wall::changeColor(float difference)
{
	// if there is any other object embedded in a wall
	// let the wall be transparent
	if (!wallIsDoor)
	{
		colors[0] = difference;
		colors[1] = 0.0;		
		colors[2] = 0.0;		
	}
}

// set the wallIsDoor flag
void wall::setWallIsDoor()
{
	wallIsDoor = TRUE;
}

// return leftEdge
float wall::getLeftEdge()
{
	return leftEdge;
}

// return rightEdge
float wall::getRightEdge()
{
	return rightEdge;
}

// return topEdge
float wall::getTopEdge()
{
	return topEdge;
}

// return bottomEdge
float wall::getBottomEdge()
{
	return bottomEdge;
}

// destructor
wall::~wall()
{}
